# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'puppet_x/enterprisemodules/oracle/mungers'

# Defines a new parameter for the ora_java_source type.
#
# @param java_name [String] The name of the Java source to manage.
# @example
#   ora_java_source { 'owner.java_name@sid':
#     ...
#   }
newparam(:java_name) do
  include EasyType

  # Description of the java_name parameter.
  #
  # This parameter represents the second part of the title for the Java source.
  #
  # @return [String] A description of the java_name parameter.
  desc <<-DESC
    The name of the java source you want to manage. The java name is the second part of the
    title.

        ora_java_source { 'owner.java_name@sid':#{'  '}
          ...
        }

  DESC

  isnamevar
  data_type('String[1]')
end
