# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

# Defines a new parameter for the ora_java_source type.
# This parameter represents the owner of the Java source.
# The owner is the first part of the title string, before the '.'.
#
# @example
#   ora_java_source { 'OWNER.JAVA_NAME@SID':
#     ...
#   }
newparam(:owner) do
  include EasyType

  # Description of the owner parameter.
  # This provides context for what the owner represents in the Java source.
  #
  # @return [String] the owner of the java source.
  desc <<-DESC
	The owner of the java source. This is the first part of the title string. The first part before
	the `.`.

      ora_java_source { 'OWNER.JAVA_NAME@SID':
        ...
      }
  DESC

  isnamevar
  data_type('String[1]')
end
