# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:content) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access
  include PuppetX::EnterpriseModules::Oracle::ProcedureHandling
  include PuppetX::EnterpriseModules::Oracle::SourceFunctions

  desc <<-DESC
  A propert describing the content of the function.

  Because puppet uses the contents of this property to decide if something needs to be done, the
  contents of this file must be very strict to the way Oracle stores the function source in the database.

  To decide if a change must be done, Puppet will fetch the function definition from the database and the contents
  of the source. For both it will remove all:

  - comments
  - empty lines
  - spaces
  - newlines
  - quotes

  and do a comparison.

  DESC

  data_type('Optional[String[1]]')

  to_translate_to_resource do |_raw_resource|
    'content-in-database'
  end

  def required_content
    @required_content ||= process_content(value)
  end
end
